From: Marti Raudsepp <marti@juffo.org>
To: cpufreq@vger.kernel.org
Cc: Dave Jones <davej@redhat.com>,
Thomas Gleixner <tglx@linutronix.de>,
Ingo Molnar <mingo@redhat.com>, "H. Peter Anvin" <hpa@zytor.com>,
x86@kernel.org, Thomas Renninger <trenn@suse.de>,
Mark Langsdorf <mark.langsdorf@amd.com>,
Rusty Russell <rusty@rustcorp.com.au>,
Andreas Herrmann <andreas.herrmann3@amd.com>,
linux-kernel@vger.kernel.org
Subject: [PATCH] powernow-k8: On load failure, remind the user to enable support in BIOS setup
Date: Wed, 20 Jan 2010 17:33:26 +0200 [thread overview]
Message-ID: <160211accaba09e778c6.1264001606@newn> (raw)
arch/x86/kernel/cpu/cpufreq/powernow-k8.c | 15 +++++++++------
1 files changed, 9 insertions(+), 6 deletions(-)
In most cases this is simply user error or bad BIOS defaults, rather than a
firmware problem.
Signed-off-by: Marti Raudsepp <marti@juffo.org>
diff --git a/arch/x86/kernel/cpu/cpufreq/powernow-k8.c b/arch/x86/kernel/cpu/cpufreq/powernow-k8.c
--- a/arch/x86/kernel/cpu/cpufreq/powernow-k8.c
+++ b/arch/x86/kernel/cpu/cpufreq/powernow-k8.c
@@ -789,17 +789,20 @@
(struct pst_s *)(psb+1), maxvid);
}
/*
* If you see this message, complain to BIOS manufacturer. If
* he tells you "we do not support Linux" or some similar
* nonsense, remember that Windows 2000 uses the same legacy
* mechanism that the old Linux PSB driver uses. Tell them it
* is broken with Windows 2000.
*
* The reference to the AMD documentation is chapter 9 in the
* BIOS and Kernel Developer's Guide, which is available on
* www.amd.com
*/
- printk(KERN_ERR FW_BUG PFX "No PSB or ACPI _PSS objects\n");
+ printk(KERN_ERR PFX "No PSB or ACPI _PSS objects\n");
+ printk(KERN_ERR PFX "Make sure that Cool'N'Quiet support is "
+ "enabled in your BIOS setup\n");
return -ENODEV;
}
next reply other threads:[~2010-01-20 15:40 UTC|newest]
Thread overview: 3+ messages / expand[flat|nested] mbox.gz Atom feed top
2010-01-20 15:33 Marti Raudsepp [this message]
2010-01-20 15:56 ` Thomas Renninger
2010-01-20 17:19 ` Marti Raudsepp
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=160211accaba09e778c6.1264001606@newn \
--to=marti@juffo.org \
--cc=andreas.herrmann3@amd.com \
--cc=cpufreq@vger.kernel.org \
--cc=davej@redhat.com \
--cc=hpa@zytor.com \
--cc=linux-kernel@vger.kernel.org \
--cc=mark.langsdorf@amd.com \
--cc=mingo@redhat.com \
--cc=rusty@rustcorp.com.au \
--cc=tglx@linutronix.de \
--cc=trenn@suse.de \
--cc=x86@kernel.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -789,17 +789,20 @@
}
/*
- * If you see this message, complain to BIOS manufacturer. If
- * he tells you "we do not support Linux" or some similar
- * nonsense, remember that Windows 2000 uses the same legacy
- * mechanism that the old Linux PSB driver uses. Tell them it
- * is broken with Windows 2000.
+ * If you see this message, check that Cool'N'Quiet is enabled
+ * in your BIOS setup. If that fails, complain to your BIOS
+ * manufacturer. If he tells you "we do not support Linux" or
+ * some similar nonsense, remember that Windows 2000 uses the
+ * same legacy mechanism that the old Linux PSB driver uses.
+ * Tell them it is broken with Windows 2000.
*
* The reference to the AMD documentation is chapter 9 in the
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
all inboxes | Powered by JetHome®